/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

/**
   Provides easy access to the private key used for transfers against
   servers configured with the default key used by Aspera Connect
 */
@interface ASConnectPrivateKey : NSObject
/** The path to the key file. This property will be nil until the key has been written to disk */
@property (nonatomic, strong, nullable) NSString *path;
/** The passphrase of the key. */
@property (nonatomic, strong, nonnull, readonly) NSString *passphrase;

/** 
    Returns the shared instance of this key
 */
+ (nonnull instancetype)sharedKey;

/**
   Writes the key to disk at the given path, returning YES on success
   and NO on failure. If the error parameters is non-nil and the write
   fails it will be populated with an error describing the failure. After 
   this methods executes successfully it sets the path attribute to the
   path value passed to this method
 */
- (BOOL)writeToDisk:(nonnull NSString *)path error:(NSError * __nullable * __nonnull)error;
@end


