//
//  ASEarUtils.h
//

/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 *
 *  Copyright (c) 2013 Aspera. All rights reserved.
 */

#import <Foundation/Foundation.h>

/// :nodoc:
extern NSString *const ASEarUtilsErrorDomain;

/**
   Decrypt files or directories encrypted by fasp via the EAR
   (encryption at rest) feature
 */
@interface ASEarUtils : NSObject


/**
   Files that were encrypted-at-rest may be decoded client-side as
   they are written to disk, or they may be written to disk still
   encrypted (in this case they will have the suffix "aspera-env"). In
   the latter case this method may be used to decrypt the files after
   the transfer has completed. A file that is decrypted will be placed
   next to the original encrypted file (without the "aspera-env"
   suffix) and, upon success, the original encrypted file will be
   deleted. If a directory is passed its contents are processed
   recursively and each file will be decrypted (subdirectories are
   also traversed). The method calls didDecryptBlock with the original
   encrypted filename for each decrypted file and will stop after its
   first failure or after all encrypted files have been decrypted.
 */
+ (BOOL)decryptPath:(NSString *)src
         passphrase:(NSString *)passphrase
              error:(NSError **)err
    didDecryptBlock:(void (^)(NSString *))didDecrypt;

/**
   Returns YES if the given path contains encrypyed files (files for
   which fileIsEncryptedContent: returns YES) and NO otherwise
 */
+ (BOOL)directoryHasEncryptedContent:(NSString *)path;

/**
   Returns YES if the given file has been encrypted using FASP's EAR
   mechanism. A file is judged to be encrypted if it ends in
   ".aspera-env" and no corresponding un-encrypted file exists (with
   the same name minus the extension "aspera-env").
 */
+ (BOOL)fileIsEncryptedContent:(NSString *)filename;

@end
