/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASAbstractFaspSession.h"

@class ASFaspSessionParameters;

/**
   A FASP session for transferring a predetermined set of files. 

   This class represents a "regular" FASP session (as opposed to
   ASPersistentFaspSession). ASFaspSession instances must be
   instantiated with the list of sources that will be transferred
   during the session.
 */
@interface ASFaspSession : ASAbstractFaspSession


/** The list of sources for this session */
@property (nonatomic, readonly, strong, nonnull) NSArray *sources;
@property (nonatomic, readonly, strong, nonnull) NSArray *destinations;

/**
   Instantiate an ASFaspSession using the given parameters and a list of sources
 */
+ (nonnull instancetype)sessionWithParameters:(nonnull ASFaspSessionParameters *)parameters sources:(nonnull NSArray *)sources;

/**
   Instantiate an ASFaspSession using the given parameters and a list of sources and corresponding destinations
 */
+ (nonnull instancetype)sessionWithParameters:(nonnull ASFaspSessionParameters *)parameters sources:(nonnull NSArray *)sources destinations:(nonnull NSArray *)destinations;

/**
   Instantiate an ASFaspSession using the given parameters and a single source
 */
+ (nonnull instancetype)sessionWithParameters:(nonnull ASFaspSessionParameters *)parameters path:(nonnull NSString *)path;

/**
   Instantiate an ASFaspSession using the given parameters and a single source and destination
 */
+ (nonnull instancetype)sessionWithParameters:(nonnull ASFaspSessionParameters *)parameters path:(nonnull NSString *)path destination:(nonnull NSString *)destinationPath;

- (nonnull instancetype)initWithParameters:(nonnull ASFaspSessionParameters *)parameters sources:(nonnull NSArray *)sources destinations:(nonnull NSArray *)destinations;

@end


