/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

/** contains statistics for a FASP session */ 
@interface ASFaspSessionStats : NSObject

/** The bytes written in the current transfer */
@property (nonatomic) unsigned long long bytesWritten;
/** The total size of the files in the session */
@property (nonatomic) unsigned long long bytesTotal;
/** The bytes remaining to be transferred */
@property (nonatomic) unsigned long long bytesRemaining;
/** The bytes already transferred */
@property (nonatomic) unsigned long long bytesTransferred;
/** The number of microsecond elapsed since the beginning of the transfer */
@property (nonatomic) unsigned long long microsecondsElapsed;
/** The number of seconds elapsed since the beginning of the transfer */
@property (nonatomic) double secondsElapsed;
/** A fractional value between 0.0 and 1.0 indicating the progress of the session */
@property (nonatomic) double progress;
/** The current instantaneous transfer rate. This rate may fluctuate and is not usually suitable for display in the UI */
@property (nonatomic) double instantaneousBitsPerSecond;
/** The current transfer rate averaged over a short period of time. This rate is stable and is suitable for display in the UI */
@property (nonatomic) double averageBitsPerSecond;
/** The average time currently remaining until the transfer completes, in seconds */
@property (nonatomic) double averageSecondsRemaining;
/** The effective rate of the transfer (in bps). Only avialable after a session ends */
@property (nonatomic) double effectiveRate;
/** The number of files whose transfer completed successfully. Only available after a session ends */
@property (nonatomic) unsigned long long filesCompleted;
/** The number of files whose transfer failed. Only available after a session ends */
@property (nonatomic) unsigned long long filesFailed;
/** The number of files that were skipped. Only available after a session ends */
@property (nonatomic) unsigned long long filesSkipped;

- (instancetype)initWithBytesWritten:(unsigned long long)bytesWritten
                bytesTotal:(unsigned long long)bytesTotal
            bytesRemaining:(unsigned long long)bytesRemaining
          bytesTransferred:(unsigned long long)bytesTransferred
       microsecondsElapsed:(unsigned long long)microsecondsElapsed
            secondsElapsed:(double)secondsElapsed
                  progress:(double)progress
instantaneousBitsPerSecond:(double)instantaneousBitsPerSecond
      averageBitsPerSecond:(double)averageBitsPerSecond
   averageSecondsRemaining:(double)averageSecondsRemaining
             effectiveRate:(double)effectiveRate
            filesCompleted:(unsigned long long)filesCompleted
               filesFailed:(unsigned long long)filesFailed
              filesSkipped:(unsigned long long)filesSkipped;
                           
- (NSString *)statsDescription;    

- (NSString *)formattedAverageRate;
- (NSString *)formattedTimeRemaining;
- (NSString *)formattedTimeElapsed;
- (NSString *)formattedSizeTotal;
- (NSString *)formattedSizeRemaining;
- (NSString *)formattedSizeTransferred;
- (NSString *)formattedEffectiveRate;

@end


