/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASAbstractFaspSession.h"

@class ASFaspSessionParameters;


/**
 A FASP session that allows adding files to the session while the transfer is running. 

 This class represents a "persistent" FASP session (as opposed to
 ASFaspSession). ASPersistentFaspSession instances are instantiated
 using only a FaspSessionParameters instance, and the paths are added
 to the session once the connection has been established. Persistent
 sessions keep their connection to the remote server until they are
 forced to close using -[ASAbstractFaspSession stop]
 */
@interface ASPersistentFaspSession : ASAbstractFaspSession

+ (instancetype)sessionWithParameters:(ASFaspSessionParameters *)parameters;

/**
   Add a file to the persistent session. This method should be called
   after the delegate method -[ASFaspSessionDelegate sessionWillStartData:] has been called and
   not before.
*/
- (void)addPathWithSource:(NSString *)src destination:(NSString *)dest;

@end


