/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASFaspSessionDelegate.h"

@class ASFaspSessionStats;
@class ASFaspSessionParameters;

/**
 * Abstract session class from which ASFaspSession and
 * ASPersistentFaspSession are derived. In practice use one of those classes
 */
@interface ASAbstractFaspSession : NSObject
/** Session UUID. This UUID is created with the session is created and never changes */
@property (nonatomic, readonly, nonnull) NSUUID *uuid;
/** Parameters with which the session was created */
@property (nonatomic, readonly, nonnull) ASFaspSessionParameters *parameters;
/** Array of ASFaspSessionDelegate instances which will receive delegate method calls for this session */
@property (nonatomic, readonly, strong, nonnull) NSMutableArray *delegates;
@property (nonatomic, strong, nonnull) NSUUID *transferUUID;
/** Current target rate of the session. Initially this equals the
    value of the initialTargetRate attribute of the
    ASFaspSessionParameters instance the session was created with. It
    may be changed using setTargetRate */
@property (nonatomic) unsigned long long targetRate;
/** Session transfer statistics */
@property (nonatomic, strong, nullable) ASFaspSessionStats *stats;
/** Contains the last error experienced by the session or nil if no error occurred */
@property (nonatomic, strong, nullable) NSError *lastError;
/** A dictionary that may be used to store custom information with the session. */
@property (nonatomic, readonly, strong, nonnull) NSMutableDictionary *userInfo;

- (nonnull instancetype)initWithParameters:(nonnull ASFaspSessionParameters *)parameters;

/**
   Start a session synchronously (this method will block until the
   session terminates)
 */
- (void)start;

/**
   Start a session asynchronously (this method returns immediately and
   the session runs in the background)
 */
- (void)startAsync;

/**
   Start a session asynchronously with a session end block. The end
   block should accept an ASAbstractFaspSession as its first argument
   and a ASFaspSessionState as its second argument. The meaning of the
   finalState parameter is the same as for the -[ASFaspSessionDelegate
   sessionDidEnd:state:] delegate callback.
 */
- (void)startAsyncWithSessionEnd:(nullable ASFaspSessionEndBlock)endBlock;

/**
   Stop the session. This method does not block and returns
   immediately. The session will continue for a short time and then
   stop. If this method is called too early in a session's lifetime or
   when a session is not running, it has no effect and returns 
   NO. Otherwise it causes the session to stop and returns YES.
 */
- (BOOL)stop;

/**
   Set the target rate for the session. This rate will take effect
   immediately if the session is running, or once the session is
   started if it is not. Note that the server may force a different 
   target rate than the one set using this method.
 */
- (void)setTargetRate:(unsigned long long)rate;
                       
- (void)generateNewTransferUUID;
@end


