/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASFaspSessionState.h"

@class ASAbstractFaspSession;

/**
   Block that is triggered when a session ends. Accepts two parameters: a non-nil ASAbstractFaspSession that should be cast as either an ASFaspSession or ASFaspPersistentSession and a session state representing the final state of the session.
 */
typedef void (^ASFaspSessionEndBlock)(ASAbstractFaspSession * __nonnull sess, ASFaspSessionState finalState);

/**
   Delegate for events triggered during a session's lifetime
*/
@protocol ASFaspSessionDelegate<NSObject>
@optional
/** Invoked at the very beginning of a session's lifetime */
- (void)sessionWillStart:(nonnull ASAbstractFaspSession *)session;
/** Invoked when a connection has been established with the remote
    host and the transfer has started */
- (void)sessionWillStartData:(nonnull ASAbstractFaspSession *)session;
/** 
 *  Invoked periodically throughout a session's lifetime to indicate progress.
 *
 *  The latest session statistics are available via the stats
 *  attribute. This delegate will be invoked at regular intervals
 *  regardless of whether or not the session's stats progress
 *  attribute changes, however, for very short transfers it may not be
 *  invoked at all
 */
- (void)sessionProgressDidChange:(nonnull ASAbstractFaspSession *)session;
/** 
 *  Invoked when transfer of a file in the session has begun. 
 *
 *  Note
 *  that this callback may be invoked multiple times (for different
 *  files) before the corresponding -[ASFaspSessionDelegate fileDidStop:] callback will be
 *  invoked (that is files in a session can be transferred in
 *  parallel) 
 */
- (void)sessionWillStartFile:(nonnull ASAbstractFaspSession *)session;
/** Invoked when transfer of a file in the session has ended. */
- (void)sessionWillStopFile:(nonnull ASAbstractFaspSession *)session;
/** 
 *  Invoked when -[ASAbstractFaspSession stop] is called. This callback signifies
 *  that the given session will be stopped, however the session may
 *  continue running for a short amount of time. The session has fully
 *  stopped when -[ASFaspSessionDelegate sessionDidEnd:] is triggered 
 */
- (void)sessionWillStop:(nonnull ASAbstractFaspSession *)session;
/** 
 *  Invoked when a session has finished transferring but before the
 *  connection with the remote host has been closed. 
 *
 *  This method
 *  precedes -[ASFaspSessionDelegate sessionDidSucceed:], -[ASFaspSessionDelegate sessionDidFail:] and
 *  -[ASFaspSessionDelegate sessionDidStop:]. 
 */
- (void)sessionDidEndData:(nonnull ASAbstractFaspSession *)session;
/** Invoked at the very end of a session's lifetime. The parameter finalState will be euqal to ASFaspSessionStateSucceeded if the session succeeds, ASFaspSessionStopped if the session was stopped using -[ASAbstractFaspSession stop], and ASFaspSessionStateFailed if the session failed (in which case the error is available via -[ASAbstractSession lastError]).
 */
- (void)sessionDidEnd:(nonnull ASAbstractFaspSession *)session state:(ASFaspSessionState)finalState;
@end


