//
//  ASLog.h
//

/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 *
 *  Copyright 2011 Aspera. All rights reserved.
 */


#ifndef __ASPERA_ASLOG__
#define __ASPERA_ASLOG__

#import "ASLogBackend.h"
#import "ASLogMacros.h"
#import "ASLogComponents.h"

#define ASULOG_GATEWAY_MAX_COMPONENTS 256



/**
   \brief (Internal)

   An object that keeps track of a list of log components, each with
   an associated modifiable log-level, and provides a mechanism for
   logging statements to an ASULog instance according to log
   component or level, where statements logged under components whose
   log levels are too low are simply ignored. This allows selectively
   enabling and disabling, with varying degrees of detail, what
   gets logged in the application during runtime.
 */
@interface ASLog : NSObject {
    ASLogComponent *components[ASULOG_GATEWAY_MAX_COMPONENTS];
}
@property (nonatomic, strong) id <ASLogBackend> logBackend;
@property (nonatomic) int numberOfComponents;
@property (nonatomic) int defaultLevel;

+ (ASLog *)defaultLog;

/**
   Initialize the log gateway with the given ASULog instance
 */
- (id)initWithLogBackend:(id <ASLogBackend>)logBackend;

/**
   Returns the maximum number of components that this log gateway can
   support (currently hard-coded at 256)
 */
- (int)maxComponents;

/**
   Log components get registered automatically when they are
   used. This method can be used to force a log comonent to
   be registered 
 */
- (bool)registerComponent:(ASLogComponent *)component;

/**
   Returns a reference to the component at the given index or NULL if
   the component is out of bounds
 */
- (ASLogComponent *)componentAtIndex:(int)index;

/**
   Logs a statement to the log file, if the given component does not
   have a current higher level
 */
- (void)component:(ASLogComponent *)component level:(int)level log:(NSString *)msg, ...;

/**
   Set all known components to the given level. Also sets the default level
 */
- (void)setAllComponentsAtLevel:(int)level;
    
@end

#endif
