//
//  ASLogBackendFile.h
//

/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 *
 *  Copyright 2011 Aspera. All rights reserved.
 */


#ifndef __ASPERA_ASLOG_BACKEND_FILE__
#define __ASPERA_ASLOG_BACKEND_FILE__

#import <Foundation/Foundation.h>
#import "ASLogBackend.h"

/**
   \brief (internal)

   Log class. Use the provided macros ASLog,
   ASDbg and ASDbg2 to log
*/
@interface ASLogBackendFile : NSObject <ASLogBackend> {
    NSString *logPath;
    NSFileHandle *logFile;
    NSDateFormatter *logFormatter;
    unsigned long long logSizeBytesThreshold;
    BOOL logToStdout;
}

@property (nonatomic, retain) NSString *logPath;
@property (nonatomic, retain) NSFileHandle *logFile;
@property (nonatomic, retain) NSDateFormatter *logFormatter;
@property (nonatomic) unsigned long long logSizeBytesThreshold;
@property (nonatomic) BOOL logToStdout;

/**
   opens a file for logging at the given path. The file
   will be created if it does not exist, and rotated if it is over
   logSizeBytesThreshold
 */
- (void)openLogAtPath:(NSString *)path;

/**
   Initializes the date formatter used by the log
 */
- (void)initLogFormatter;

/**
   Opens the file at the given path for writing and stores the
   file handle in a static variable. The file must already
   exist. Once the file is opened the position is changed to
   the end of the file and two newlines written there. This
   method may be safely called multiple times
 */
- (void)openFileForWritingAtPath:(NSString *)path;

/**
   Creates an empty file at the given path if none exists, or,
   if the file is above logSizeBytesThreshold,
   rotates the log
 */
- (void)createOrRotateFileAtPath:(NSString *)path;

/**
   Performs most of the work for
   -[AsperaLog createOrRotateFileAtPath:]
 */
- (void)rotateFileAtPath:(NSString *)path;

/**
   Convenience method for determining the size of a file at the given
   path. If the file does not exist 0 is returned
 */
- (unsigned long long)sizeForFileAtPath:(NSString *)path;

/**
   Creates a file at the given path and inserts an intro message on
   the first line, along the lines of "log created <date-time>", where
   <date-time> is a string representation of the current time
 */
- (void)createFileAtPath:(NSString *)path;

/**
   Closes the log file and deallocates the NSDateFormatter instance
   used for logging. This method should be called prior to application
   termination to avoid leaking the file descriptor used for the log
   file
 */
- (void)finalization;

/**
   Returns the current time as a string
 */
- (NSString *)currentTimeAsString;

/**
   Returns the intro message used by
   -[ASLogBackendFile createFileAtPath:], as an NSData instance
 */
- (NSData *)introMessageAsData;


@end

#endif
