//
//  ASULogGatewayMacros.h
//

/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 *
 *  Copyright (c) 2012 Aspera. All rights reserved.
 */

#ifndef __ASPERA_ASLOG_MACROS__
#define __ASPERA_ASLOG_MACROS__


#define ASLogComponentAtLevel(comp, lvl, str,...) [[ASLog defaultLog] component:(&comp) level:(lvl) log:(str),##__VA_ARGS__]

#define ASLogError(comp, str,...)    ASLogComponentAtLevel(comp, ASLogLevelError, str,##__VA_ARGS__)
#define ASLogWarn(comp, str,...)     ASLogComponentAtLevel(comp, ASLogLevelWarn, str,##__VA_ARGS__)
#define ASLogInfo(comp, str,...)     ASLogComponentAtLevel(comp, ASLogLevelInfo, str,##__VA_ARGS__)
#define ASLogDebug(comp, str,...)    ASLogComponentAtLevel(comp, ASLogLevelDebug, str,##__VA_ARGS__)
#define ASLogDebug2(comp, str,...)   ASLogComponentAtLevel(comp, ASLogLevelDebug2, str,##__VA_ARGS__)
#define ASLogDebug3(comp, str,...)   ASLogComponentAtLevel(comp, ASLogLevelDebug3, str,##__VA_ARGS__)

// Legacy macros for backward compatibility with ASULogGateway/ASULog
#define ASLog(comp, str,...) ASLogInfo(comp, str, ##__VA_ARGS__)
#define ASDbg(comp, str,...) ASLogDebug(comp, str, ##__VA_ARGS__)
#define ASDbg2(comp, str,...) ASLogDebug2(comp, str, ##__VA_ARGS__)
#define ASDbg3(comp, str,...) ASLogDebug3(comp, str, ##__VA_ARGS__)

/**
   Returns true if the given component has the given level enabled
 */
#define ASLogLevelEnabled(comp, level) (level <= comp.level)

/**
   Returns true if the given component is enabled at level 0
 */
#define ASLogEnabled(comp) ASLogLevelEnabled(comp, 0)

/**
   Returns true if the given component is enabled at level 1
 */
#define ASDbgEnabled(comp) ASLogLevelEnabled(comp, 1)

/**
   Returns true if the given component is enabled at level 2
 */
#define ASDbg2Enabled(comp) ASLogLevelEnabled(comp, 2)

/**
   Defines a log component with the given string label and level -1
 */
#define ASLogDefineComponent(LABEL) {-1, LABEL, -1}

/**
   Defines a log component with the given string label and level
 */
#define ASLogDefineComponentLevel(LABEL, LEVEL) {-1, LABEL, LEVEL}

#endif
