/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

@class ASFaspSessionParameters;

/**
   A class for testing session credentials and connectivity parameters

   This class can be used to test if a given ASFaspSessionParameters
   instance contains correct connectivity and credential parameters.
   When the test method of the class is called it will connect to the
   host specified in the parameters and attempt SSH authentication
   (either via password or private key depending on the parameters). 
 */
@interface ASParametersConnectionTest : NSObject 
@property (nonatomic, strong, readonly) ASFaspSessionParameters *parameters;
- (instancetype)initWithParameters:(ASFaspSessionParameters *)parameters;
/**
  Attempt to establish a connection and perform SSH authentication
  with the host specified in the parameters. This method blocks. It
  returns YES on success and NO on failure. On failure the error
  pointer, if non-nil, will be set with an error describing the
  failure.
 */
- (BOOL)testWithError:(NSError **)err;

/**
   Performs the same test as testWithError: but asynchronously,
   invoking the success or failure blocks depending on the outcome of
   the test
 */
- (void)testAsyncWithSuccess:(void(^)())successBlock failure:(void(^)(NSError*))failureBlock;
@end


