/*
 *  Licensed Materials - Property of IBM
 *  IBM Product Name: 5725S57
 *  Copyright IBM Corp. 2011, 2015
 *  US Government Users Restricted Rights - Use, 
 *  duplication or disclosure restricted by GSA 
 *  ADP Schedule Contract with IBM Corp.
 */

#import "ASFaspSessionDelegate.h"
#import "AsperaLog.h"

@class ASAbstractFaspSession;
@class ASFaspSession;
@class ASFaspSessionParameters;
@class ASPersistentFaspSession;
@class ASSessionStartNotifier;

/// :nodoc:
struct faspapi_session_state_t;
/// :nodoc:
typedef struct faspapi_session_state_t faspapi_session_state_t;

/// :nodoc:
void ASLogSetLevel(ASLogComponent *comp, int level);

/// :nodoc:
@interface ASTransferEngine : NSObject 
@property (nonatomic) int initResultCode;
@property (nonatomic, strong) ASAbstractFaspSession *currentSession;
@property (nonatomic) BOOL stopSessionRequested;
@property (nonatomic) BOOL stopSessionPerformed;
@property (nonatomic, strong) ASSessionStartNotifier *startNotifier;
@property (nonatomic, strong) NSLock *faspInitLock;

+ (instancetype)sharedTransferEngine;
- (void)initializeFaspapi;
- (NSError *)testParameters:(ASFaspSessionParameters *)params;
- (void)startSession:(ASAbstractFaspSession *)session
          sessionEnd:(ASFaspSessionEndBlock)endBlock;
- (BOOL)stopSession:(ASAbstractFaspSession *)session;
- (void)persistentSession:(ASPersistentFaspSession *)session 
        addPathWithSource:(NSString *)path 
              destination:(NSString *)dest;
- (void)setTargetRate:(unsigned long long)rate
           forSession:(ASAbstractFaspSession *)session;

- (void)faspSessionCallbackForEvent:(int)event sessionState:(faspapi_session_state_t *)session_state;
- (void)setFaspapiLogLevel:(int)level;
+ (NSString *)sdkVersion;

@end


